import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, min, max, extent, format} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 25,
  bottom: 75,
  left: 100,
};


const xValue = (d) => d.sepal_length;
const xAxisLabel = 'Sepal Length';
const xAxisLabelOffset = 60;

const yValue = (d) => d.sepal_width;
const yAxisLabel = 'Sepal Width';
const yAxisLabelOffset = 55;

const siFormat = format(".2s");
// we move the si format to its own thing
// because it would keep invoking / creating otherwise?
const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  console.log(data[0]);

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, innerHeight]);

  

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset = {5}
        />
        <text
          className="axis-label"
          text-anchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight / 2}) rotate(-90) `}
        >
          {yAxisLabel}
        </text>
        <AxisLeft yScale={yScale} innerWidth ={innerWidth} tickOffset = {8} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          text-anchor="middle"
          y={innerHeight + xAxisLabelOffset}
        >
          {xAxisLabel}
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat= {xAxisTickFormat}
          circleRadius = {7}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
